@@ -31,7 +31,9 @@ language_list=(
     '"Persian"    fa'
     '"Polish"     pl'
     '"Romanian"   ro'
+    '"Russian"    ru'
     '"Spanish"    es'
+    '"Swedish"    sv'
     '"Ukrainian"  uk'
 )
 
